@@ -55,12 +55,12 @@ class Client:
         return len(self.bot.users)
 
     async def post_data(self):
-        print("POSTING")
         bot_id = str(self.bot.user.id)
         key = self.key
         servers = str(self.servers)
         users = str(self.users)
         data = {"id":bot_id,"key":key,"servers":servers,"users":users,"commands":str(self.commands),"active":str(len(self.active)),"popular":self.popular}
+        print(data)
         self.active = []
         self.commands = 0
         self.popular = []
